OH_CursorInfo_Create

Function OH_CursorInfo_Create 

pub unsafe extern "C" fn OH_CursorInfo_Create(
    left: f64,
    top: f64,
    width: f64,
    height: f64,
) -> *mut InputMethod_CursorInfo
@brief Create a new {@link InputMethod_CursorInfo} instance.

@param left The left point of the cursor and must be absolute coordinate of the physical screen. @param top The top point of the cursor and must be absolute coordinate of the physical screen. @param width The width of the cursor. @param height The height of the cursor. @return If the creation succeeds, a pointer to the newly created {@link InputMethod_CursorInfo} instance is returned. If the creation fails, NULL is returned, possible cause is insufficient memory. @since 12