OH_CursorInfo_SetRect

Function OH_CursorInfo_SetRect 

pub unsafe extern "C" fn OH_CursorInfo_SetRect(
    cursorInfo: *mut InputMethod_CursorInfo,
    left: f64,
    top: f64,
    width: f64,
    height: f64,
) -> InputMethod_ErrorCode
@brief Set cursor info.

@param cursorInfo Represents a pointer to an {@link InputMethod_CursorInfo} instance. @param left The left point of the cursor and must be absolute coordinate of the physical screen. @param top The top point of the cursor and must be absolute coordinate of the physical screen. @param width The width of the cursor. @param height The height of the cursor. @return Returns a specific error code. {@link IME_ERR_OK} - success. {@link IME_ERR_NULL_POINTER} - unexpected null pointer. Specific error codes can be referenced {@link InputMethod_ErrorCode}. @since 12