OH_InputMethodController_Attach

Function OH_InputMethodController_Attach 

pub unsafe extern "C" fn OH_InputMethodController_Attach(
    textEditorProxy: *mut InputMethod_TextEditorProxy,
    options: *mut InputMethod_AttachOptions,
    inputMethodProxy: *mut *mut InputMethod_InputMethodProxy,
) -> InputMethod_ErrorCode
@brief Attach application to the input method service.

@param textEditorProxy Represents a pointer to an {@link InputMethod_TextEditorProxy} instance. The caller needs to manage the lifecycle of textEditorProxy. If the call succeeds, caller cannot release textEditorProxy until the next attach or detach call. @param options Represents a pointer to an {@link InputMethod_AttachOptions} instance. The options when attaching input method. @param inputMethodProxy Represents a pointer to an {@link InputMethod_InputMethodProxy} instance. Lifecycle is mantianed until the next attach or detach call. @return Returns a specific error code. {@link IME_ERR_OK} - success. {@link IME_ERR_PARAMCHECK} - parameter check failed. {@link IME_ERR_IMCLIENT} - input method client error. {@link IME_ERR_IMMS} - input method manager service error. {@link IME_ERR_NULL_POINTER} - unexpected null pointer. Specific error codes can be referenced {@link InputMethod_ErrorCode}. @since 12